/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include "Value.hpp"
#include <cmath>

using namespace std;
using namespace Dxc;

Value::Value()
{
}

IntegerValue::IntegerValue(int value) : value_(value)
{
}

ostream &IntegerValue::put(ostream &out) const
{
    out << value_;

    return out;
}

int IntegerValue::get() const
{
    return value_;
}

BoolValue::BoolValue(bool value) : value_(value)
{
}

ostream &BoolValue::put(ostream &out) const
{
    out << (value_ ? "true" : "false");

    return out;
}

bool BoolValue::get() const
{
    return value_;
}

RealValue::RealValue(double value) : value_(value)
{
}

ostream &RealValue::put(ostream &out) const
{
    out << value_;
    long double d;

    if ( modf(value_, &d) == 0.0)
        out << ".0";

    return out;
}

double RealValue::get() const
{
    return value_;
}

StringValue::StringValue(const string *value) : value_(value)
{
}

ostream &StringValue::put(ostream &out) const
{
    out << "'" << *value_ << "'";

    return out;
}

string StringValue::get() const
{
    return *value_;
}

ostream & operator << (ostream &out, const Dxc::Value *value)
{
    return value->put(out);
}
