/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.connection;

import org.dxc.api.DxcCallback;

/**
 * Factory class for creating DxcConnectors.
 * 
 * DA developers should call the getDAConnector() static factory method to
 * obtain a DxcConnector with which to begin sending and receiving data.
 */
public class ConnectorFactory {
    /**
     * Static factory method for creating a DxcConnector for use by a Diagnosis
     * Algorithm
     * 
     * @param callback
     *            The user's DxcCallback implementation, to be executed upon
     *            arrival of DxcData.
     */
    public static DxcConnector getDAConnector(DxcCallback callback) {
        return new DAConnector(callback);
    }

    // Other factory methods are for internal use and will most likely soon be
    // removed.
    public static DxcConnector getStandaloneSDSConnector(DxcCallback callback) {
        return new StandaloneSDSConnector(callback);
    }
}
