/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.connection;

import java.io.IOException;
import java.io.PrintStream;
import java.net.Socket;

import org.dxc.api.DxcCallback;
import org.dxc.api.DxcConfig;
import org.dxc.api.datatypes.DxcData;

public class StandaloneSDSConnector extends DxcConnector implements
        ConnectionCallback {
    private PrintStream sdsStream;

    protected StandaloneSDSConnector(DxcCallback c) {
        super(c);

        try {
            listen(DxcConfig.getInstance().get("SDS_DA_PORT"), this);
            listen(DxcConfig.getInstance().get("SR_DA_PORT"), null);
        } catch (IOException ex) {
            System.out.println("StandaloneSDSConnector unable to connect.\n");
        } catch (Exception ex) {
            System.out.println(ex.getMessage());
        }
    }

    public void connectionMade(Socket s, int listenPort) {
        try {
            this.sdsStream = new PrintStream(s.getOutputStream());
        } catch (IOException ex) {
            System.out.println("SDS unable to read from socket.\n");
        }
    }

    public void sendMessage(DxcData d) {
        if (sdsStream != null)
            d.put(sdsStream);

        if (this.callback != null)
            this.callback.onDataReceived(d);
    }
}