/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.PrintStream;

/**
 * Data structure for DA profiling messages.
 */
public class ProfilingData extends DxcData {

    private long maxMem;
    private long cpuTime;

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp.
     * @param cpuTime
     *            - Total process cpu time
     * @param maxMem
     *            - Maximum process memory usage
     */
    public ProfilingData(long timestamp, long cpuTime, long maxMem) {
        super(timestamp);
        this.cpuTime = cpuTime;
        this.maxMem = maxMem;
    }

    /**
     * Constructs with timestamp set to current time.
     * 
     * @param cpuTime
     *            - Total process cpu time
     * @param maxMem
     *            - Maximum process memory usage
     */
    public ProfilingData(long cpuTime, long maxMem) {
        super();
        this.cpuTime = cpuTime;
        this.maxMem = maxMem;
    }

    /**
     * Returns total process cpu time.
     */
    public long getCpuTime() {
        return this.cpuTime;
    }

    /**
     * Returns maximum process memory usage.
     */
    public long getMaxMem() {
        return this.maxMem;
    }

    public PrintStream put(PrintStream out) {
        out.append("profilingInfo @");
        out.append(Long.toString(this.getTimeStamp()));
        out.append(" cpuTime = " + this.cpuTime);
        out.append(", maxMem = " + this.maxMem + ";\n");
        return out;
    }
}