/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.PrintStream;

/**
 * Data structure for scenario status messages.
 */
public class ScenarioStatusData extends DxcData {

    private String status;

    public static final String SDS_AWAITING_DA = "SDS_AWAITING_DA";

    public static final String SR_READY = "SR_READY";

    /**
     * A Diagnosis Algorithm sends DA_READY to indicate it's prepared to receive
     * data.
     */
    public static final String DA_READY = "DA_READY";

    public static final String STARTED = "SCENARIO_STARTED";

    /**
     * Signals scenario end, DAs must finalize and exit properly or risk
     * termination.
     * 
     * Some time is given to DAs to compute and send final diagnoses (the exact
     * time is determined by the DXC config file), after which they are
     * terminated.
     */
    public static final String ENDED = "SCENARIO_ENDED";

    public static final String DA_ENDED = "DA_TERMINATED";

    public static final String UNKNOWN = "UNKNOWN";

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp.
     * @param status
     *            - current scenario status (ScenarioStatusData::STARTED,
     *            ScenarioStatusData::ENDED, etc).
     */
    public ScenarioStatusData(long timestamp, String status) {
        super(timestamp);
        if (status.equals(SDS_AWAITING_DA) || status.equalsIgnoreCase(DA_READY)
                || status.equals(SR_READY) || status.equals(STARTED)
                || status.equals(ENDED)) {

            this.status = status;
        } else {
            this.status = UNKNOWN;
        }
    }

    /**
     * Constructs with timestamp set to current time.
     * 
     * @param status
     *            - current scenario status (ScenarioStatusData::STARTED,
     *            ScenarioStatusData::ENDED, etc).
     */
    public ScenarioStatusData(String status) {
        super();
        if (status == SDS_AWAITING_DA || status == DA_READY
                || status == SR_READY || status == STARTED || status == ENDED) {

            this.status = status;
        } else {
            this.status = UNKNOWN;
        }
    }

    /**
     * Returns status.
     */
    public String getStatus() {
        return this.status;
    }

    public PrintStream put(PrintStream out) {
        out.append("scenarioStatus @");
        out.append(Long.toString(this.getTimeStamp()));
        out.append(" " + status + ";\n");
        return out;
    }
}