/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Iterator;

/**
 * Data structure for sensor data messages.
 */
public class SensorData extends DxcData {

    private Map<String, Value> sensors;

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp.
     * @param sensors
     *            - map containing data points for each sensor.
     */
    public SensorData(long timestamp, Map<String, Value> sensors) {
        super(timestamp);
        this.sensors = (sensors == null) ? new HashMap<String, Value>()
                : sensors;
    }

    /**
     * Returns the map from sensor to Value.
     * 
     * If the type of datapoint is unknown (it should be made known, for example
     * through an XML system catalog), the Value type for each point must be
     * determined by trial and error (using RTTI or dynamic_cast null tests).
     */
    public Map<String, Value> getSensorValueMap() {
        return sensors;
    }

    public PrintStream put(PrintStream out) {
        out.append("sensors @");
        out.append(Long.toString(this.getTimeStamp()));

        out.append(" { ");

        boolean fg = false;
        Iterator<String> i = sensors.keySet().iterator();
        while (i.hasNext()) {
            String s = i.next();

            if (fg) {
                out.append(", ");
            } else {
                fg = true;
            }
            out.append(s + " = ");
            sensors.get(s).put(out);
        }
        out.append(" };\n");

        return out;
    }
}