package org.dxc.evaluator;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;
import java.util.Map;

public class ConfusionMatrix {
    private double[][] matrix;
    private double count;
    private Map<String, Integer> idxLookup;

    public static String NOMINAL = "Nominal";

    public ConfusionMatrix(Set<String> modes) {
        matrix = new double[modes.size()][modes.size()];
        idxLookup = new HashMap<String, Integer>();
        count = 0;

        Iterator<String> i = modes.iterator();
        int n = 0;

        while (i.hasNext()) {
            idxLookup.put(i.next(), n++);
        }
    }

    public void addPrediction(String actual, String predicted, double weight) {
        int act = idxLookup.get(actual);
        int pre;
        try {
            pre = idxLookup.get(predicted);
        } catch (Exception ex) {
            pre = idxLookup.get(NOMINAL);
            System.out.println("Unknown fault mode ID in diagnosis: "
                    + predicted);
        }
        matrix[act][pre] += weight;
        count += weight;
    }

    public double percentCorrect() {
        double total = 0;
        for (int i = 0; i < matrix.length; i++) {
            total += matrix[i][i];
        }
        return total / (double) count;
    }
}
