/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.evaluator;

import org.dxc.api.DxcConfig;
import org.dxc.api.parser.DxcParser;

import java.io.File;
import java.io.FileReader;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public class Evaluator {
    private static Map<String, DAResult> daResults;

    public static void main(String[] args) {
        daResults = new HashMap<String, DAResult>();

        try {
            String dir = DxcConfig.getInstance().get("RESULTS_DIR");
            File resultsDir = new File(dir);
            String[] contents = resultsDir.list();

            for (int i = 0; i < contents.length; i++)
                if (contents[i].endsWith(".scn"))
                    processScenario(dir + contents[i]);

        } catch (Exception ex) {
            System.out.append(ex.toString() + " " + ex.getMessage());
        }

        Iterator<DAResult> i = daResults.values().iterator();
        if (!i.hasNext())
            System.out.println("No results. Exiting.");

        while (i.hasNext()) {
            printResult(i.next());
            System.out.println();
        }
    }

    private static void processScenario(String filename) throws Exception {
        FileReader input = new FileReader(filename);
        String daSystemPair = filename.substring(
                filename.lastIndexOf('\\') + 1, filename.lastIndexOf(" - "));

        ScenarioResult sr = new ScenarioResult(filename);
        DxcParser parser = new DxcParser(sr, input);
        parser.beginParse();

        DAResult dar;
        if (daResults.containsKey(daSystemPair)) {
            dar = daResults.get(daSystemPair);
        } else {
            String daName = daSystemPair.substring(0, daSystemPair
                    .lastIndexOf(" - "));
            String system = daSystemPair.substring(daSystemPair
                    .lastIndexOf(" - ") + 3);
            dar = new DAResult(daName, system);
            daResults.put(daSystemPair, dar);
        }

        dar.addScenario(sr);
    }

    private static void printResult(DAResult dar) {
        DecimalFormatSymbols dfs = new DecimalFormatSymbols();
        dfs.setNaN("[undefined]");
        DecimalFormat df = new DecimalFormat("0.0###", dfs);

        System.out.println("DA: " + dar.getDAName());
        System.out.println("System: " + dar.getSystem());
        System.out.println("False Positives Rate: "
                + df.format(dar.getFalsePositivesRate()));
        System.out.println("False Negatives Rate: "
                + df.format(dar.getFalseNegativesRate()));
        System.out.println("Detection Accuracy: "
                + df.format(dar.getDetectionAccuracy()));
        System.out.println("Isolation Accuracy: "
                + df.format(dar.getIsolationAccuracy()));
        System.out.print("Mean Time To Detect: ");
        if (Double.isNaN(dar.getMeanTimeToDetection()))
            System.out.println("[undefined]");
        else
            System.out.println(df.format(dar.getMeanTimeToDetection()) + " ms");
        System.out.print("Mean Time To Isolate: ");
        if (Double.isNaN(dar.getMeanTimeToIsolation()))
            System.out.println("[undefined]");
        else
            System.out.println(df.format(dar.getMeanTimeToIsolation()) + " ms");
        System.out.println("Mean Cpu Time (ms): "
                + df.format(dar.getMeanCpuTime()) + " ms");
        System.out.println("Mean Peak Memory Usage: "
                + df.format(dar.getMeanMemUsage() / 1024.0) + " Kb");
    }
}
