/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef _WIN32

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <cassert>
#include <errno.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

#include <DataTypes/DxcException.hpp>
#include <LinuxFileLister.hpp>

using namespace Dxc;
using namespace std;

vector<string> LinuxFileLister::getDirectories(string directory)
{
    struct dirent **nameList;

    int n = scandir(directory.c_str(), &nameList, NULL, NULL);
    if (n < 0)
    {
        throw DxcException(strerror(errno));
    }

    vector<string> result;
    for (int i = 0; i < n; i++)
    {
        struct stat s;

        stat((directory + "/" + string(nameList[i]->d_name)).c_str(), &s);
        if (nameList[i]->d_name[0] != '.' && S_ISDIR(s.st_mode))
        {
            result.push_back(string(nameList[i]->d_name) + "/");
        }
        free(nameList[i]);
    }
    free(nameList);

    return result;
}

vector<string> LinuxFileLister::getFiles(string directory)
{
    struct dirent **nameList;

    int n = scandir(directory.c_str(), &nameList, NULL, NULL);
    if (n < 0)
    {
        throw DxcException(strerror(errno));
    }

    vector<string> result;
    for (int i = 0; i < n; i++)
    {
        struct stat s;

        stat((directory + "/" + string(nameList[i]->d_name)).c_str(), &s);
        if (nameList[i]->d_name[0] != '.' && !S_ISDIR(s.st_mode))
        {
            result.push_back(string(nameList[i]->d_name));
        }
        free(nameList[i]);
    }
    free(nameList);

    return result;
}

#endif
