/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <DataTypes/DxcException.hpp>
#include <ProcessFactory.hpp>
#include <JavaLoader.hpp>

#ifdef _WIN32
#include <WinExeLoader.hpp>
#define ExeLoader WinExeLoader

#define RUN_WIN_DA 1
#define RUN_LINUX_DA 0
#define RUN_JAVA_DA 1

#else
#include <LinuxExeLoader.hpp>
#define ExeLoader LinuxExeLoader

#define RUN_WIN_DA 0
#define RUN_LINUX_DA 1
#define RUN_JAVA_DA 1

#endif

using namespace Dxc;
using namespace std;

ProcessLoader* ProcessFactory::createProcessLoader(const string& name,
        const string& directory,
        const string& args)
{
    if (name.find(".jar", name.length() - 4) != string::npos)
        // not currently needed
        void();
    else
        return new ExeLoader(name, directory, args);

    throw DxcException(name + ": Unable to create process.");
    return NULL;
}

ProcessLoader* ProcessFactory::createDAProcessLoader(const DAConfig& daConf,
        const string& system)
{
    if ((daConf.getPlatform() == "Java" ||
            daConf.getPlatform() == "java") &&
            RUN_JAVA_DA)
    {
        return new JavaLoader(daConf.getBinName(),
                              daConf.getJavaClass(),
                              daConf.getDirectory(),
                              daConf.getArgs(system));
    }
    else if ((daConf.getPlatform() == "Windows" ||
              daConf.getPlatform() == "windows") &&
             RUN_WIN_DA)
    {
        return new ExeLoader(daConf.getBinName(),
                             daConf.getDirectory(),
                             daConf.getArgs(system));
    }
    else if ((daConf.getPlatform() == "Linux" ||
              daConf.getPlatform() == "linux") &&
             RUN_LINUX_DA)
    {
        return new ExeLoader(daConf.getBinName(),
                             daConf.getDirectory(),
                             daConf.getArgs(system));
    }

    throw DxcException(daConf.getBinName() + ": Unable to create process.");
    return NULL;
}
